@@ -37,7 +37,7 @@ class PreCommandJobPrivate
 {
 public:
     PreCommandJobPrivate(PrecommandJob *parent);
-    QProcess *process;
+    QProcess *process = nullptr;
     QString precommand;
     PrecommandJob *q;
 
@@ -59,11 +59,16 @@ PrecommandJob::PrecommandJob(const QString &precommand, QObject *parent)
 {
     d->precommand = precommand;
     d->process = new QProcess(this);
-    connect(d->process, SIGNAL(started()), SLOT(slotStarted()));
-    connect(d->process, SIGNAL(error(QProcess::ProcessError)),
-            SLOT(slotError(QProcess::ProcessError)));
-    connect(d->process, SIGNAL(finished(int,QProcess::ExitStatus)),
-            SLOT(slotFinished(int,QProcess::ExitStatus)));
+    connect(d->process, &QProcess::started, this, [this]() {
+        d->slotStarted();
+    });
+    connect(d->process, &QProcess::errorOccurred, this, [this](QProcess::ProcessError error) {
+        d->slotError(error);
+    });
+    connect(d->process, qOverload<int, QProcess::ExitStatus>(&QProcess::finished),
+            this, [this](int val, QProcess::ExitStatus status) {
+        d->slotFinished(val, status);
+    });
 }
 
 PrecommandJob::~PrecommandJob()
